@@ -14,8 +14,8 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
 
 
@@ -373,6 +373,21 @@ void read_configfile(const char *filename,struct cvsd_cfg *cfg)
         cfg->cvscmd=xstrdup(opts[1]);
       }
     }
+    else if (strcmp(opts[0],"CvsArgs")==0)
+    {
+      if (nopts<2)
+      {
+        log_log(LOG_ERR,"%s:%d: CvsArgs: wrong number of arguments",filename,lnr);
+        exit(1);
+      }
+      for (i=1;i<nopts;i++)
+      {
+        /* TODO: check if arguments look like valid cvs parameters and issue warning otherwise */
+        tmp=(char *)xmalloc((strlen(opts[i])+1)*sizeof(char));
+        strcpy(tmp,opts[i]);
+        cfg_addcvsarg(cfg,tmp);
+      }
+    }
     else if (strcmp(opts[0],"Limit")==0)
     {
 #ifdef HAVE_SETRLIMIT
