@@ -15,7 +15,7 @@
    Copyright (C) 1999 Chris Black.
    Copyright (C) 2000 Philippe Kehl.
    Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009,
-                 2010, 2011 Arthur de Jong.
+                 2010, 2011, 2012 Arthur de Jong.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -124,7 +124,7 @@ static void display_version(FILE *fp)
 {
   fprintf(fp,"%s\n",PACKAGE_STRING);
   fprintf(fp,"Written by Chris Black, Philippe Kehl and Arthur de Jong.\n\n");
-  fprintf(fp,"Copyright (C) 1999-2011 Chris Black, Philippe Kehl and Arthur de Jong.\n"
+  fprintf(fp,"Copyright (C) 1999-2012 Chris Black, Philippe Kehl and Arthur de Jong.\n"
              "This is free software; see the source for copying conditions.  There is NO\n"
              "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n");
 }
