@@ -1,7 +1,7 @@
 /*
    xmalloc.c - malloc wrapper
 
-   Copyright (C) 2002, 2003 Arthur de Jong.
+   Copyright (C) 2002, 2003, 2007 Arthur de Jong.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -43,7 +43,7 @@ void *xmalloc(size_t size)
 char *xstrdup(const char *s)
 {
   char *tmp;
-  int l;
+  size_t l;
   if (s==NULL)
   {
     log_log(LOG_CRIT,"xstrdup() called with NULL");
